IF OBJECT_ID('[Environments_Extended]') IS NOT NULL
	DROP VIEW [Environments_Extended]
GO

CREATE VIEW [Environments_Extended]
AS

	SELECT E.*
          ,[Parent_Environment_Name] = E_PARENT.[Environment_Name]
          
          ,[Roles_Count] = (SELECT COUNT(DISTINCT SRS.[ServerRole_Id])
                              FROM [EnvironmentServers] ES
                       CROSS APPLY dbo.Environments_GetAncestorEnvironments(ES.[Environment_Id]) AE
                        INNER JOIN [ServerRoleServers] SRS
                                ON SRS.[Server_Id] = ES.[Server_Id]
                             WHERE AE.[Environment_Id] = E.[Environment_Id])
          
          ,[Servers_Count] = (SELECT COUNT(DISTINCT ES.[Server_Id])
                              FROM [EnvironmentServers] ES
                       CROSS APPLY dbo.Environments_GetAncestorEnvironments(ES.[Environment_Id]) AE
                             WHERE AE.[Environment_Id] = E.[Environment_Id])
          
          ,[Aggregate_ServerConfiguration_Status_Code] = COALESCE((
                SELECT TOP 1 SC.[ServerConfiguration_Status_Code]
                  FROM [EnvironmentServers] ES 
                 INNER JOIN [ServerConfigurations] SC
                         ON ES.[Server_Id] = SC.[Server_Id]
                 WHERE ES.[Environment_Id] = E.[Environment_Id]

                ORDER BY CHARINDEX(SC.[ServerConfiguration_Status_Code], 'DC')
            ), 'U')

          ,[Descendants_Aggregate_ServerConfiguration_Status_Code] = COALESCE((
                SELECT TOP 1 SC.[ServerConfiguration_Status_Code]
                  FROM [EnvironmentServers] ES 
                 CROSS APPLY dbo.Environments_GetAncestorEnvironments(ES.[Environment_Id]) AE
                 INNER JOIN [ServerConfigurations] SC
                         ON ES.[Server_Id] = SC.[Server_Id]
                 WHERE AE.[Environment_Id] = E.[Environment_Id]

                ORDER BY CHARINDEX(SC.[ServerConfiguration_Status_Code], 'DC')
            ), 'U')

	  FROM [Environments] E
 
 LEFT JOIN [Environments] E_PARENT
        ON E_PARENT.[Environment_Id] = E.[Parent_Environment_Id]

GO
