EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CompleteExecution',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Completes an execution.'
GO

IF OBJECT_ID('[Executions_CompleteExecution]') IS NOT NULL DROP PROCEDURE [Executions_CompleteExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CompleteExecution]
(
	@Execution_Id INT,
	@End_Date DATETIME = NULL,
	@ExecutionStatus_Code CHAR(1) = NULL,
	@DriftDetected_Indicator YNINDICATOR = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @ExecutionStatus_Code IS NULL
	BEGIN
		DECLARE @Max_LogEntry_Level INT

		SELECT @Max_LogEntry_Level = MAX([LogEntry_Level])
		  FROM [ScopedExecutionLogEntries]
		 WHERE [Execution_Id] = @Execution_Id

		SET @Max_LogEntry_Level = COALESCE(@Max_LogEntry_Level, 0)
		IF @Max_LogEntry_Level < 20
			SET @ExecutionStatus_Code = 'S'
		ELSE IF @Max_LogEntry_Level < 30
			SET @ExecutionStatus_Code = 'W'
		ELSE
			SET @ExecutionStatus_Code = 'E'
	END

	UPDATE [Executions]
	   SET [End_Date] = COALESCE(@End_Date, GETUTCDATE()),
	       [ExecutionStatus_Code] = @ExecutionStatus_Code,
           [ExecutionRunState_Code] = 'C'
	 WHERE [Execution_Id] = @Execution_Id

	 IF @DriftDetected_Indicator IS NOT NULL BEGIN
		UPDATE [PlanExecutions]
		   SET [DriftDetected_Indicator] = @DriftDetected_Indicator
		 WHERE [Execution_Id] = @Execution_Id
	 END

     UPDATE [ScopedExecutionLogs]
        SET [End_Date] = @End_Date,
            [HighestLogEntry_Level] = (SELECT MAX([LogEntry_Level])
		                                 FROM [ScopedExecutionLogEntries] L2
								        WHERE [Execution_Id] = @Execution_Id
                                          AND L2.[Scope_Sequence] = L.[Scope_Sequence])
       FROM [ScopedExecutionLogs] L
      WHERE [Execution_Id] = @Execution_Id
        AND [End_Date] IS NULL

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Executions_CompleteExecution] TO [OtterUser_Role]
