EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_ServiceStartCleanup',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Fault running jobs, complete any incomplete executions, and complete log scopes with no end date.'
GO

IF OBJECT_ID('[Executions_ServiceStartCleanup]') IS NOT NULL DROP PROCEDURE [Executions_ServiceStartCleanup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_ServiceStartCleanup]
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    -- complete all executions and put them in error status
    UPDATE [Executions]
       SET [ExecutionRunState_Code] = 'C',
           [ExecutionStatus_Code] = 'E'
     WHERE [End_Date] IS NULL

    -- fault all running jobs
    UPDATE [Jobs]
       SET [JobState_Code] = 'F'
     WHERE [JobState_Code] = 'R'

    -- set highest log entry and end date for scoped logs that never completed
	UPDATE [ScopedExecutionLogs]
	   SET [End_Date] = GETUTCDATE(),
	       [HighestLogEntry_Level] = (SELECT MAX([LogEntry_Level])
		                            FROM [ScopedExecutionLogEntries] LE
								   WHERE LE.[Execution_Id] = L.[Execution_Id]
								     AND LE.[Scope_Sequence] = L.[Scope_Sequence])
      FROM [ScopedExecutionLogs] L
     WHERE [End_Date] IS NULL

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Executions_ServiceStartCleanup] TO [OtterUser_Role]
